"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = _interopRequireWildcard(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _lodash = _interopRequireDefault(require("lodash.get"));

var _utils = _interopRequireDefault(require("./utils"));

var _constants = require("./constants");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function () { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

const ContentfulImage = (0, _react.forwardRef)(({
  format,
  optimize,
  resize,
  cropRadius,
  quality,
  backgroundColor,
  image,
  ...imageProps
}, ref) => {
  const imageData = (0, _react.useMemo)(() => {
    const originalUrl = typeof image === 'string' ? image : (0, _lodash.default)(image, 'fields.file.url');

    if (!originalUrl) {
      return;
    }

    const urlParameters = [];
    let returnedMimeType;

    if (optimize) {
      const {
        url,
        mimeType
      } = (0, _utils.default)({
        key: _constants.FORMAT,
        value: format
      });
      urlParameters.push(...url);
      returnedMimeType = mimeType;
    }

    if (resize) {
      const url = (0, _utils.default)({
        key: _constants.RESIZE,
        value: resize
      });
      urlParameters.push(...url);
    }

    if (cropRadius) {
      const url = (0, _utils.default)({
        key: _constants.CROP,
        value: cropRadius
      });
      urlParameters.push(...url);
    }

    if (quality) {
      const url = (0, _utils.default)({
        key: _constants.QUALITY,
        value: quality
      });
      urlParameters.push(...url);
    }

    if (backgroundColor) {
      const url = (0, _utils.default)({
        key: _constants.BACKGROUND_COLOR,
        value: backgroundColor
      });
      urlParameters.push(...url);
    }

    const enhancedUrl = urlParameters.length ? `${originalUrl}?${urlParameters.join('&')}` : originalUrl;
    return {
      enhancedUrl,
      mimeType: returnedMimeType,
      originalUrl
    };
  }, [image, format, resize, optimize, cropRadius, quality, backgroundColor]);

  if (!imageData) {
    console.error('ContentfulImage: Could not retrieve an URL from the `image` prop. Please check your object structure.');
    return null;
  }

  const {
    enhancedUrl,
    mimeType,
    originalUrl
  } = imageData;
  return /*#__PURE__*/_react.default.createElement("picture", {
    "data-testid": "picture"
  }, enhancedUrl !== originalUrl && /*#__PURE__*/_react.default.createElement("source", {
    srcSet: enhancedUrl,
    type: mimeType
  }), /*#__PURE__*/_react.default.createElement("source", {
    srcSet: originalUrl
  }), /*#__PURE__*/_react.default.createElement("img", Object.assign({}, imageProps, {
    src: originalUrl,
    ref: ref
  })));
});
ContentfulImage.propTypes = {
  optimize: _propTypes.default.bool,
  quality: _propTypes.default.number,
  image: _propTypes.default.oneOfType([_propTypes.default.string, _propTypes.default.object]).isRequired,
  backgroundColor: _propTypes.default.string,
  cropRadius: _propTypes.default.oneOfType([_propTypes.default.oneOf(['max']), _propTypes.default.number]),
  format: _propTypes.default.oneOf(['webp', 'jpg', 'png', 'progressive jpg', '8bit png']),
  resize: _propTypes.default.shape({
    width: _propTypes.default.number,
    height: _propTypes.default.number,
    behavior: _propTypes.default.oneOf(['pad', 'fill', 'scale', 'crop', 'thumb']),
    focusArea: _propTypes.default.oneOf(['top', 'right', 'bottom', 'left', 'center', 'top_right', 'top_left', 'bottom_right', 'bottom_left', 'face', 'faces'])
  })
};
ContentfulImage.defaultProps = {
  format: 'webp',
  optimize: true
};
var _default = ContentfulImage;
exports.default = _default;
module.exports = exports.default;