"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _constants = require("../constants");

var _mappers = require("./mappers");

const buildUrlParametersFormat = ({
  key,
  value
}) => {
  const conversion = value.split(' ');
  const formatParameter = _mappers.parametersMapper[key].format;
  const compressionParameter = _mappers.parametersMapper[key].compression;

  if (conversion.length === 2) {
    const compressionValue = _mappers.valuesMapper[key].compression[conversion[0]];
    const url = `${formatParameter}=${conversion[1]}&${compressionParameter}=${compressionValue}`;
    return {
      url: [url],
      mimeType: `image/${_mappers.valuesMapper[key].mimeType[conversion[1]]}`
    };
  }

  const url = `${formatParameter}=${conversion[0]}`;
  return {
    url: [url],
    mimeType: `image/${_mappers.valuesMapper[key].mimeType[conversion[0]]}`
  };
};

const buildUrlParametersResize = ({
  key,
  value
}) => {
  const resizeParameters = Object.keys(value).map(element => {
    const parameter = _mappers.parametersMapper[key][element];
    return `${parameter}=${value[element]}`;
  });
  return resizeParameters;
};

const buildSimpleUrlParameter = ({
  key,
  value
}) => {
  const parameter = _mappers.parametersMapper[key];
  return [`${parameter}=${value}`];
};

const buildUrlParameterBackgroundColor = ({
  key,
  value
}) => {
  const parameter = _mappers.parametersMapper[key];
  const finalValue = value.replace('#', 'rgb:');
  return [`${parameter}=${finalValue}`];
};

const buildUrlParameters = options => {
  const {
    key
  } = options;

  switch (key) {
    case _constants.FORMAT:
      return buildUrlParametersFormat(options);

    case _constants.RESIZE:
      return buildUrlParametersResize(options);

    case _constants.CROP:
    case _constants.QUALITY:
      return buildSimpleUrlParameter(options);

    case _constants.BACKGROUND_COLOR:
      return buildUrlParameterBackgroundColor(options);

    default:
      break;
  }
};

var _default = buildUrlParameters;
exports.default = _default;
module.exports = exports.default;